@@ -1,11 +1,12 @@
 /* Variables and structures for declaration processing.
-   Copyright (C) 1993, 2000, 2002, 2004, 2005 Free Software Foundation, Inc.
+   Copyright (C) 1993, 2000, 2002, 2004, 2005, 2007, 2008
+   Free Software Foundation, Inc.
 
 This file is part of GCC.
 
 GCC is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
+the Free Software Foundation; either version 3, or (at your option)
 any later version.
 
 GCC is distributed in the hope that it will be useful,
@@ -14,9 +15,8 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with GCC; see the file COPYING.  If not, write to
-the Free Software Foundation, 59 Temple Place - Suite 330,
-Boston, MA 02111-1307, USA.  */
+along with GCC; see the file COPYING3.  If not see
+<http://www.gnu.org/licenses/>.  */
 
 /* In grokdeclarator, distinguish syntactic contexts of declarators.  */
 enum decl_context
@@ -27,10 +27,24 @@ enum decl_context
   FIELD,			/* Declaration inside struct or union */
   BITFIELD,			/* Likewise but with specified width */
   TYPENAME,			/* Typename (inside cast or sizeof)  */
+  TEMPLATE_TYPE_ARG,		/* Almost the same as TYPENAME  */
   MEMFUNCDEF			/* Member function definition */
 };
 
 /* We need this in here to get the decl_context definition.  */
-extern tree grokdeclarator (const cp_declarator *, 
-			    const cp_decl_specifier_seq *, 
+extern tree grokdeclarator (const cp_declarator *,
+			    const cp_decl_specifier_seq *,
 			    enum decl_context, int, tree*);
+
+/* States indicating how grokdeclarator() should handle declspecs marked
+   with __attribute__((deprecated)).  An object declared as
+   __attribute__((deprecated)) suppresses warnings of uses of other
+   deprecated items.  */
+
+enum deprecated_states {
+  DEPRECATED_NORMAL,
+  DEPRECATED_SUPPRESS
+};
+
+extern enum deprecated_states deprecated_state;
+
